;; Generated package description from osc.el  -*- no-byte-compile: t -*-
(define-package "osc" "0.4.0.20220930.145438" "Open Sound Control protocol library" 'nil :commit "e17861b7c4309574478da11b2af1bf58d7d613a9" :url "https://elpa.gnu.org/packages/osc.html" :authors '(("Mario Lang" . "mlang@blind.guru")) :maintainer '("Mario Lang" . "mlang@blind.guru") :keywords '("comm" "processes" "multimedia"))
